@@ -1,10 +1,11 @@
 from .Image import Image
-from .Meta import Meta, TrainingMeta
+from .Meta import Meta, TrainingMeta, EvaluationMeta
 from .Model import Model
 
 __all__ = [
     Image,
     Meta,
     Model,
-    TrainingMeta
+    TrainingMeta,
+    EvaluationMeta
 ]
