@@ -2,7 +2,6 @@ from captur_ml_sdk.dtypes.generics import Image, Meta, Model
 from captur_ml_sdk.utils import get_image_components
 from captur_ml_sdk.dtypes.exceptions import InvalidFilePathError
 from captur_ml_sdk.dtypes.interfaces.validators import (
-    ensure_file_exists,
     check_images_or_imagesfile_is_included,
     enforce_mutual_exclusivity_between_images_and_imagesfile
 )
@@ -29,11 +28,6 @@ class Data(BaseModel):
             raise ValueError(str(e))
         return v
 
-    _ensure_file_exists_imagesfile = validator(
-        'imagesfile', allow_reuse=True)(ensure_file_exists)
-    _ensure_file_exists_labelsfile = validator(
-        'labelsfile', allow_reuse=True)(ensure_file_exists)
-
     _images_or_imagesfile_ = root_validator(
         check_images_or_imagesfile_is_included, allow_reuse=True)
     _mutual_exclusivity = root_validator(
