@@ -5,17 +5,13 @@ from pydantic import (
 
 from typing import Optional, List
 
-from captur_ml_sdk.dtypes.generics import Image
+from captur_ml_sdk.dtypes.generics import Image, Meta
 from captur_ml_sdk.dtypes.interfaces.validators import check_images_or_imagefile_has_data
 
 
-class OfflinePreRunEventData_MetaField(BaseModel):
-    webhooks: Optional[HttpUrl]
-
-
 class OfflinePreRunEventData(BaseModel):
     request_id: str
-    meta: Optional[OfflinePreRunEventData_MetaField]
+    meta: Optional[Meta]
     images: Optional[List[Image]]
     imagesfile: Optional[str]
     model_name: str
